@@ -1,13 +1,16 @@
+from collections import Counter
 from itertools import chain
-from typing import Hashable, Iterable, Optional, Sequence, Union
+from typing import Hashable, Iterable, List, Optional, Sequence, Tuple, Union
 
-import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
+from matplotlib import colors, pyplot, ticker
 from scipy.stats import entropy
 
 
 class DiversityMetrics:
+    clist: List[Tuple] = [(0, "red"), (0.5, "orange"), (1, "yellow")]
+
     @staticmethod
     def _get_histogram(
         items: Union[Iterable[Hashable], Iterable[Sequence[Hashable]]],
@@ -66,9 +69,28 @@ class DiversityMetrics:
         categories_histogram = cls._get_histogram(items)[::-1]
         scaled_prefix_sum = categories_histogram.cumsum() / categories_histogram.sum()
         lorenz_curve: np.ndarray = np.insert(scaled_prefix_sum, 0, 0)
-        _, ax = plt.subplots()
+        _, ax = pyplot.subplots()
         x_axis: np.ndarray = np.linspace(0.0, 1.0, lorenz_curve.size)
         ax.fill_between(x_axis, 0, lorenz_curve, alpha=0.3)
         ax.fill_between(x_axis, lorenz_curve, x_axis, alpha=0.3)
-        plt.plot(x_axis, lorenz_curve)
-        plt.savefig("Lorenz.png")
+        pyplot.plot(x_axis, lorenz_curve)
+        pyplot.savefig("Lorenz.png")
+
+    @classmethod
+    def get_distribution(
+        cls, items: Union[Iterable[Hashable], Iterable[Sequence[Hashable]]]
+    ) -> pd.DataFrame:
+        if isinstance(next(iter(items)), Sequence):
+            items = chain(*items)
+        counter: pd.DataFrame = pd.DataFrame(Counter(items).most_common())
+        counter.columns = pd.Index(["category", "percentage"])
+        counter["percentage"] /= counter["percentage"].sum()
+        rvb = colors.LinearSegmentedColormap.from_list("", cls.clist)
+        counter_len = len(counter)
+        x = np.arange(counter_len).astype(float)
+        y = counter["percentage"]
+        pyplot.style.use("seaborn")
+        pyplot.bar(x, y, color=rvb(x / counter_len))
+        pyplot.gca().yaxis.set_major_formatter(ticker.PercentFormatter(1, 2))
+        pyplot.savefig("distribution.png")
+        return counter
